summaryrefslogtreecommitdiffstats
path: root/src/dotfrontend.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/dotfrontend.cpp')
-rw-r--r--src/dotfrontend.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/dotfrontend.cpp b/src/dotfrontend.cpp
index e0cfbed..69e825d 100644
--- a/src/dotfrontend.cpp
+++ b/src/dotfrontend.cpp
@@ -25,8 +25,8 @@
*
***************************************************************************/
-#include <qfileinfo.h>
-#include <qpaintdevicemetrics.h>
+#include <ntqfileinfo.h>
+#include <ntqpaintdevicemetrics.h>
#include <kmessagebox.h>
#include <klocale.h>
#include "dotfrontend.h"
@@ -55,11 +55,11 @@ DotFrontend::~DotFrontend()
* description
* @return true if successful, false otherwise
*/
-bool DotFrontend::run(const QString& sFile)
+bool DotFrontend::run(const TQString& sFile)
{
- QString sPath;
- QStringList slArgs;
- QPaintDeviceMetrics pdm(m_pGraph);
+ TQString sPath;
+ TQStringList slArgs;
+ TQPaintDeviceMetrics pdm(m_pGraph);
// Set the horizontal and vertical DPI values
m_dDpiX = (double)pdm.logicalDpiX();
@@ -90,9 +90,9 @@ bool DotFrontend::run(const QString& sFile)
* @return true if the file in the given path exists and has executable
* permissions, false otherwise
*/
-bool DotFrontend::verify(const QString& sPath)
+bool DotFrontend::verify(const TQString& sPath)
{
- QFileInfo fi(sPath);
+ TQFileInfo fi(sPath);
if (!fi.exists() || !fi.isFile() || !fi.isExecutable() ||
fi.fileName() != "dot") {
@@ -114,12 +114,12 @@ bool DotFrontend::verify(const QString& sPath)
* @return A value indicating the way this token should be treated: dropped,
* added to the token queue, or finishes a new record
*/
-Frontend::ParseResult DotFrontend::parseStdout(QString& sToken,
+Frontend::ParseResult DotFrontend::parseStdout(TQString& sToken,
ParserDelim delim)
{
static int nWidth, nHeight, nXpos, nYpos, nCurveSize, nCurveCount;
- static QPointArray arrCurve;
- static QString sNode, sEdgeHead, sEdgeTail;
+ static TQPointArray arrCurve;
+ static TQString sNode, sEdgeHead, sEdgeTail;
ParseResult result = DiscardToken;
double dVal;
bool bOK;
@@ -214,7 +214,7 @@ Frontend::ParseResult DotFrontend::parseStdout(QString& sToken,
nHeight = (int)(dVal * m_dDpiY);
// Create the bounding rectangle of the node
- QRect rect;
+ TQRect rect;
rect.setX(nXpos - (nWidth / 2));
rect.setY(nYpos - (nHeight / 2));
rect.setWidth(nWidth);
@@ -272,7 +272,7 @@ Frontend::ParseResult DotFrontend::parseStdout(QString& sToken,
// Draw the edge
m_pGraph->drawEdge(sEdgeHead, sEdgeTail, arrCurve);
// Must detach from contents since a QPointArray shares data
arrCurve.detach();
m_state = EndNodeEdge;
@@ -272,7 +272,7 @@ Frontend::ParseResult DotFrontend::parseStdout(QString& sToken,
// Draw the edge
m_pGraph->drawEdge(sEdgeHead, sEdgeTail, arrCurve);
- // Must detach from contents since a QPointArray shares data
+ // Must detach from contents since a TQPointArray shares data
arrCurve.detach();
m_state = EndNodeEdge;